@@ -289,6 +289,7 @@ class Cursor(DBAPICursor):
         _logger.info("getting result metadata")
         buffer = client.getResultMetadata(self._query_id)
         buffer = BytesIO(buffer)
+        self.rows_count = 0
         self._rowcount, self._query_columns_description = get_query_columns_info(buffer)
         _logger.info("finished populating metadata")
         return
@@ -302,10 +303,10 @@ class Cursor(DBAPICursor):
         batch_size = self._arraysize
         self._data = list()
         for i in range(batch_size):
-            row = self.fetchone()
+            rows = self.fetch_batch()
             if row is None:
                 return
-            self._data.append(row)
+            self._data = self._data + rows
 
         _logger.info("fetched batch of {num}".format(num=len(self._data)))
         return self._data
@@ -317,6 +318,8 @@ class Cursor(DBAPICursor):
             _logger.info(len(self._data))
             _logger.info("fetching next batch from fetch all")
             rows = self.fetch_batch()
+            if rows is None:
+                return None
             self._data = self._data + rows
         return self._data
 
@@ -339,13 +342,16 @@ class Cursor(DBAPICursor):
     def fetchmany(self, size=10000):
         _logger.info("fetching all from overriden method")
         size = min(size, self.rowcount())
-        row_count = 0
+        self.rows_count = 0
         self._data = list()
-        while row_count < size:
+        while self.rows_count < size:
             _logger.info("fetching next batch from fetch many")
             _logger.info(len(self._data))
+            _logger.info("no  of rows accumulated ".format(self.rows_count))
             rows = self.fetch_batch()
-            row_count = row_count + len(rows)
+            if rows is None:
+                return None
+            self.rows_count = self.rows_count + len(rows)
             self._data = self._data + rows
         return self._data if len(self._data) == size else self._data[0:size]
 
