@@ -22,7 +22,7 @@ from sqlalchemy import types
 from sqlalchemy import util
 # TODO shouldn't use mysql type
 from sqlalchemy.databases import mysql
-from sqlalchemy.engine import default, Engine, Connection, URL
+from sqlalchemy.engine import default, Engine, Connection
 from sqlalchemy.sql import compiler
 from sqlalchemy.sql.compiler import SQLCompiler
 
